# Generated by Django 2.2.2 on 2020-03-18 17:06

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Mail',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(editable=False, verbose_name='Created')),
                ('updated', models.DateTimeField(editable=False, verbose_name='Updated')),
                ('subject', models.CharField(blank=True, max_length=250, verbose_name='Subject')),
                ('to_address', models.TextField(verbose_name='To')),
                ('cc_address', models.TextField(blank=True, verbose_name='CC')),
                ('bcc_address', models.TextField(blank=True, verbose_name='BCC')),
                ('from_address', models.EmailField(max_length=250, verbose_name='From')),
                ('content', models.TextField(blank=True, verbose_name='Content')),
                ('html_content', models.TextField(blank=True, verbose_name='HTML Content')),
                ('errors', models.TextField(blank=True, default='', verbose_name='Content')),
                ('sent', models.DateTimeField(blank=True, null=True)),
            ],
            options={
                'ordering': ['updated'],
                'abstract': False,
            },
        ),
    ]



from django.contrib import admin

from .models import Mail, Event


@admin.register(Mail)
class MailAdmin(admin.ModelAdmin):
    list_display = ['created', 'to_address', 'from_address']


@admin.register(Event)
class EventAdmin(admin.ModelAdmin):
    list_display = ['created', 'related_user', 'meta']



from traceback import format_exc

from django.utils.translation import ugettext_lazy as _
from django.utils import timezone
from django.db import models
from django.core.mail import send_mail
from django.conf import settings


class CoreModel(models.Model):
    created = models.DateTimeField(
        'Created',
        editable=False,
        null=False,
        blank=False,
    )

    updated = models.DateTimeField(
        'Updated',
        editable=False,
        null=False,
        blank=False,
    )

    def save(self, *args, **kwargs):
        if self.created is None:
            self.created = timezone.now()
        self.updated = timezone.now()
        return super(CoreModel, self).save(*args, **kwargs)

    class Meta:
        abstract = True
        ordering = ['updated']


class Mail(CoreModel):
    subject = models.CharField(_('Subject'), max_length=250, blank=True)
    to_address = models.TextField(_('To'))
    cc_address = models.TextField(_('CC'), blank=True)
    bcc_address = models.TextField(_('BCC'), blank=True)
    from_address = models.EmailField(_('From'), max_length=250)
    content = models.TextField(_('Content'), blank=True)
    html_content = models.TextField(_('HTML Content'), blank=True)

    errors = models.TextField(_('Content'), blank=True, default='')
    sent = models.DateTimeField(blank=True, null=True)

    def send(self):
        try:

            send_mail(
                self.subject,
                self.content,
                self.from_address,
                [self.to_address],
                fail_silently=False,
            )
            self.sent = timezone.now()
        except: # noqa
            self.error = format_exc()

        self.save()


class Event(CoreModel):
    type = models.CharField(_('Type'), max_length=256, blank=False, null=False)
    related_user = models.ForeignKey(
        getattr(settings, 'AUTH_USER_MODEL', 'auth.User'),
        null=True,
        blank=True,
        related_name='events',
        on_delete=models.CASCADE,
    )
    meta = models.TextField(blank=True, null=False, default='')



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ttcore",
    version="0.0.3",
    author="Martin F",
    author_email="pypi.org@tigerteamx.com",
    description="Django functionality to speedup development",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/tigerteamx/ttcore",
    packages=setuptools.find_packages(),
    install_requires=['Django >= 2.0',
                      "django-cron==0.5.1"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



from django.conf import settings

from django_common.helper import send_mail

from django_cron import CronJobBase, Schedule, get_class
from django_cron.models import CronJobLog


class FailedRunsNotificationCronJob(CronJobBase):
    """
    Send email if cron failed to run X times in a row
    """
    RUN_EVERY_MINS = 30

    schedule = Schedule(run_every_mins=RUN_EVERY_MINS)
    code = 'cronhelper.FailedRunsNotificationCronJob'

    def do(self):

        crons_to_check = [get_class(x) for x in settings.CRON_CLASSES]
        emails = ['m@pinehq.com']

        failed_runs_cronjob_email_prefix = \
            getattr(settings, 'FAILED_RUNS_CRONJOB_EMAIL_PREFIX', '')

        for cron in crons_to_check:
            min_failures = getattr(cron, 'MIN_NUM_FAILURES', 10)
            jobs = CronJobLog.objects.\
                filter(code=cron.code).order_by('-end_time')[:min_failures]
            failures = 0
            message = ''

            for job in jobs:
                if not job.is_success:
                    failures += 1
                    message += 'Job ran at %s : \n\n %s \n\n' % (
                        job.start_time, job.message)

            if failures >= min_failures:
                send_mail(
                    '%s%s failed %s times in a row!' % (
                        failed_runs_cronjob_email_prefix,
                        cron.code,
                        min_failures,
                    ),
                    message,
                    settings.DEFAULT_FROM_EMAIL, emails
                )
